==> v1.10.4.zip: wcs/wcs/qommon/__init__.py <==
# w.c.s. - web application for online forms
# Copyright (C) 2005-2010  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

from quixote import enable_ptl, get_publisher

enable_ptl()

import sys
# Make ihooks works under Python 2.6 and Quixote < 2.7, the problem is that
# ihooks is broken AND deprecated, and is removed in Python 3 without being
# repaired before and there no transition module.
# The exact problem is that the ihooks __import__ implementation does not
# handle the last argument 'level', which is used to do 'relatives' import
if sys.version_info >= (2, 6):
    import __builtin__
    import ihooks
    if ihooks.current_importer:
        __old_importer = __builtin__.__import__
        __very_old_importer = ihooks.current_importer.save_import_module
    def __import_wrapper(name, globals={}, locals={}, fromlist=[], level=-1): 
        if level == -1:
            return __old_importer(name, globals, locals, fromlist)
        else:
            return __very_old_importer(name, globals, locals, fromlist, level)
    if ihooks.current_importer:
        __builtin__.__import__ = __import_wrapper

from publisher import get_cfg, get_logger

try:
    import lasso
except ImportError:
    lasso = None

if lasso:
    if not hasattr(lasso, 'SAML2_SUPPORT'):
        lasso.SAML2_SUPPORT = False
    if not hasattr(lasso, 'SAML2_NAME_IDENTIFIER_FORMAT_EMAIL'):
        lasso.SAML2_NAME_IDENTIFIER_FORMAT_EMAIL = 'urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress'
    if not hasattr(lasso, 'SAML2_NAME_IDENTIFIER_FORMAT_UNSPECIFIED'):
        lasso.SAML2_NAME_IDENTIFIER_FORMAT_EMAIL = 'urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified'

    if not hasattr(lasso, 'cptrToPy') and not hasattr(lasso, 'OrigProvider'):
        lasso.OrigProvider = lasso.Provider
        # old (SWIG) bindings
        class Provider(lasso.OrigProvider):
            def __init__(self, *args):
                lasso.OrigProvider.__init__(self, *args)
                if self.this is None:
                    raise lasso.Error('Error creating Provider')
        lasso.Provider = Provider

from vendor import timeoutsocket

__version__ = "$Rev$"

==> v1.12.9.zip: wcs/wcs/qommon/__init__.py <==
# w.c.s. - web application for online forms
# Copyright (C) 2005-2010  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

from quixote import get_publisher
from publisher import get_cfg, get_logger

try:
    import lasso
except ImportError:
    lasso = None

if lasso:
    if not hasattr(lasso, 'SAML2_SUPPORT'):
        lasso.SAML2_SUPPORT = False
    if not hasattr(lasso, 'SAML2_NAME_IDENTIFIER_FORMAT_EMAIL'):
        lasso.SAML2_NAME_IDENTIFIER_FORMAT_EMAIL = 'urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress'
    if not hasattr(lasso, 'SAML2_NAME_IDENTIFIER_FORMAT_UNSPECIFIED'):
        lasso.SAML2_NAME_IDENTIFIER_FORMAT_EMAIL = 'urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified'

    if not hasattr(lasso, 'cptrToPy') and not hasattr(lasso, 'OrigProvider'):
        lasso.OrigProvider = lasso.Provider
        # old (SWIG) bindings
        class Provider(lasso.OrigProvider):
            def __init__(self, *args):
                lasso.OrigProvider.__init__(self, *args)
                if self.this is None:
                    raise lasso.Error('Error creating Provider')
        lasso.Provider = Provider

from vendor import timeoutsocket

__version__ = "$Rev$"
